/*
  Jind - an interpreter for a toy programming language
  Copyright (C) 2000, 2001 Markus Triska

  This program is free software; you can redistribute it and/or modify
  it under the terms of the GNU General Public License as published by
  the Free Software Foundation; either version 2 of the License, or
  (at your option) any later version.

  This program is distributed in the hope that it will be useful,
  but WITHOUT ANY WARRANTY; without even the implied warranty of
  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
  GNU General Public License for more details.

  You should have received a copy of the GNU General Public License
  along with this program; if not, write to the Free Software
  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111 USA

  Contact me at triska@gmx.at
*/

public class Field
{
    int numcols = 50;
    int numrows = 20;

    String mymap = new String(" ==================================================|      XXXXX                                     ||        XXX                                     ||         XX       XXXXXXXXXXXXXXXXXXXXXXXXXXXXXX||         XX       X        X       XX          X||          X       X        X      X      XXXXX X||          X       X        X    XX    XXXX     X||          X       X         XXXX      XXXXXXXXXX||          XXXXXXXXX                        XXXXX||                                               X||                                                ||                                                ||                         X                      ||                         X      XXXXXX  XXXXXXXX||XXXXXXXXX                X     XX       XXXXXXXX||        X       XXXXXX   X     X  XX           X||   XX   X      XX        X     X  X       XXXXXX||   XXXXXX      XX        X    X  X              ||   XXXX       XXX        XXXXX    X             ||             XXXX        XXXX     X             ||             XXXX        XXXXXX   XXXX          |==================================================");

    /*
      ==================================================
      |      XXXXX                                     |
      |        XXX                                     |
      |         XX       XXXXXXXXXXXXXXXXXXXXXXXXXXXXXX|
      |         XX       X        X       XX          X|
      |          X       X        X      X      XXXXX X|
      |          X       X        X    XX    XXXX     X|
      |          X       X         XXXX      XXXXXXXXXX|
      |          XXXXXXXXX                        XXXXX|
      |                                               X|
      |                                                |
      |                                                |
      |                         X                      |
      |                         X      XXXXXX  XXXXXXXX|
      |XXXXXXXXX                X     XX       XXXXXXXX|
      |        X       XXXXXX   X     X  XX           X|
      |   XX   X      XX        X     X  X       XXXXXX|
      |   XXXXXX      XX        X    X  X              |
      |   XXXX       XXX        XXXXX    X             |
      |             XXXX        XXXX     X             |
      |             XXXX        XXXXXX   XXXX          |
      ==================================================
    */


    byte[][] field = new byte[numcols + 1][numrows + 1];

    int iterate_row;
    int iterate_col;

    public Field(String map)
    {
	int j = 0,k;
	for (j = 0; j <= numcols; j++) {
	    for (k = 0; k <= numrows; k++) {
		field[j][k] = Globals.FREE;
	    }
	}

	// Draw border
	for (int i = 0; i <= numcols; i++) {
	    field[i][0] = Globals.BLOCK;
	    field[i][numrows] = Globals.BLOCK;
	    if (i < numrows) {
		field[0][i] = Globals.BLOCK;
		field[numcols][i] = Globals.BLOCK;
	    }
	}

	char[] mychars = mymap.toCharArray();
	for (int loop1 = 0; loop1 < mymap.length(); loop1++) {
	    switch(mychars[loop1]) {
	    case 'X': field[loop1 % numcols][loop1 / numcols] = Globals.BLOCK;
	    }
	}

	field[1][4] = Globals.BLOCK;
	field[2][4] = Globals.BLOCK;
	field[1][5] = Globals.BLOCK;

    }

    public void startIteration()
    {
	iterate_row = -1;
	iterate_col = -1;
    }

    public boolean nextRow()
    {
	if (iterate_row >= numrows) return false;
	iterate_row += 1;
	iterate_col = -1;
	return true;
    }

    public boolean nextCol()
    {
	if (iterate_col >= numcols) return false;
	iterate_col += 1;
	return true;
    }

    public byte getPiece()
    {
	return field[iterate_col][iterate_row];
    }

    public boolean test(Position pos, byte what)
    {
	return (field[pos.x][pos.y] == what);
    }
}

